Ever had a project idea that looks to take advantage of the NHL API, but you don't know where to start
because there's no documentation?

Look no further!

This api wrapper was developed to make grabbing and using that data a snap!

**Here's what you get:**

1. A few classes to make this simple
2. Built in methods on those classes, to make the data gathering a breeze

For questions or suggestions please create an issue @ https://github.com/branks42/easy-nhl